.. -*- coding: utf-8 -*-

Changelog
=========

0.2.post0 (2017-05-31)
----------------------
- Release universal wheels
  [gforcada]

0.2 (2017-05-31)
----------------
- Added support for sublimetext (stdin/filename handling)
  [iham]

0.1 (2015-09-15)
----------------
- Initial release
  [gforcada]

- Create the flake8 plugin per se.
  [gforcada]

